@@ -1,11 +1,12 @@
 from __future__ import annotations
 
 from copy import deepcopy
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from datetime import datetime
-from typing import Any, Dict
+from typing import Any, Dict, Tuple
 
 from ctlml_commons.util.date_utils import convert_dates
+from ctlml_commons.util.entity_utils import separate_fields
 from ctlml_commons.util.num_utils import convert_floats
 
 
@@ -26,10 +27,17 @@ class Quote:
     last_trade_price_source: str
     instrument: str
     updated_at: datetime
+    other: field(default_factory=dict)
 
     @classmethod
     def deserialize(cls, input_data: Dict[str, Any]) -> Quote:
-        return Quote(**cls.clean(input_data=input_data))
+        known, other = cls.separate(cls.clean(input_data=input_data))
+
+        return cls(**known, other=other)
+
+    @classmethod
+    def separate(cls, input_data: Dict[str, Any]) -> Tuple[Dict[str, Any], Dict[str, Any]]:
+        return separate_fields(known_fields=cls.__dataclass_fields__.keys(), input_data=input_data)
 
     @classmethod
     def clean(cls, input_data: Dict[str, Any]) -> Dict[str, Any]:
