@@ -27,6 +27,9 @@ class TimeInForce(Enum):
     def to_enum(value: str) -> TimeInForce:
         return TimeInForce.mapping()[value.lower()]
 
+    def value(self) -> str:
+        return TimeInForce.from_enum(value=self)
+
     @classmethod
     def from_enum(cls, value: TimeInForce) -> str:
         return TimeInForce.reverse_mapping()[value]
